var HitDetails = function()
{
	var details = {};
	
	// Page initialization
	details.initPage = function()
	{
		Buttons.addClickHandler('close', App.closeWindow);
		var url = 'Hit.servlet?ID='+App.getSessionId();
		url += '&cmd=GetDetails';
		url += '&rbaId='+Data.int('page-data', 'rba');
		url += '&fileId='+Data.int('page-data', 'file');
		url += '&lineNo='+Data.int('page-data', 'line');
		url += '&idx='+encodeURIComponent(Data.get('page-data', 'idx'));
		
		Wizard.asyncJsonRequest(url, details.detailsLoaded);
	}
	
	details.detailsLoaded = function(response)
	{
		Doc.show('variant');
		var rba = response.rba;
		var file = response.file;
		var hit = response.hit;
		
		document.title += ' - ' + hit['#CHROM']+':'+hit.POS;
		Doc.element('doc-title').innerHTML = Strings.encodeTags(rba.name + ' - ' + hit['#CHROM']+':'+hit.POS);
		
		var html = '';
		html += '<tr><th>Variant call</th><td>'+Strings.encodeTags(rba.name)+'</td></tr>';
		html += '<tr><th>File</th><td>'+Strings.encodeTags(file.name)+'</td></tr>';
		
		// Genetype, depth, etc. and other sample-specific values
		html += '<tr><th>Genotype</th><td style="border-top-width: 1px; border-top-style: dotted;">'+Strings.encodeTags(hit.GT);
		html += ' <b title="Depth">DP</b> '+Strings.encodeTags(hit.DP);
		html += ' <b title="Variant depth">VD</b> '+Strings.encodeTags(hit.VD);
		html += ' <b title="Allelic depths for the ref and alt alleles">AD</b> '+Strings.encodeTags(hit.AD);
		html += ' <b title="Allele Frequency">AF</b> '+Strings.encodeTags(hit.AF);
		html += '</td></tr>';
		
		// Location and change at genomic and protein level and other effects
		html += '<tr><th>Gene</th><td style="border-top-width: 1px; border-top-style: dotted;">'+Strings.encodeTags(hit.genes)+'</td></tr>';
		var chr = hit['#CHROM'];
		var pos = hit.POS;
		var lpos = parseInt(pos);
		html += '<tr><th>Location</th><td>';
		html += '<a target="_blank" title="View in Genome Browser (new window)"';
		html += ' href="http://genome.ucsc.edu/cgi-bin/hgTracks?db=hg38';
		html += '&position='+encodeURIComponent(chr+':'+(lpos-30)+'-'+(lpos+30));
		html += '&highlight='+encodeURIComponent(chr+':'+pos+'-'+pos)+'">';
		html += Strings.encodeTags(chr+':'+pos)+'</a></td></tr>';
		html += '<tr><th>Type</th><td>'+Strings.encodeTags(hit.TYPE)+'</td></tr>';
		html += '<tr><th>Effect</th><td>'+Strings.encodeTags(hit.effect)+'</td></tr>';
		html += '<tr><th>Ref › Alt</th><td>'+details.refAlt(hit.REF, hit.ALT)+'</td></tr>';
		html += '<tr><th>HGVS.c</th><td>'+Strings.encodeTags(hit.hgvsc)+'</td></tr>';
		html += '<tr><th>HGVS.p</th><td>'+Strings.encodeTags(hit.hgvsp)+'</td></tr>';
		
		// dbSNP
		html += '<tr><th>dbSNP</th><td style="border-top-width: 1px; border-top-style: dotted;">';
		if (hit.dbsnp_ID)
		{
			html += '<a target="_blank" title="View in dbSNP (new window)"';
			html += ' href="https://www.ncbi.nlm.nih.gov/snp/'+encodeURIComponent(hit.dbsnp_ID)+'">';
			html += Strings.encodeTags(hit.dbsnp_ID)+"</a>";
		}
		html += '</td></tr>';
		
		// COSMIC
		html += '<tr><th>COSMIC</th><td>';
		if (hit.cosmic_ID)
		{
			html += '<a target="_blank" title="View in COSMIC (new window)"';
			html += ' href="https://cancer.sanger.ac.uk/cosmic/search?q='+encodeURIComponent(hit.cosmic_ID)+'">';
			html += Strings.encodeTags(hit.cosmic_ID)+'</a>';
		}
		if (hit.cosmic_WES_BRCA_MF)
		{
			html += ' <b title="Mutant Frequency in WGS/WES breast cancer samples">MF</b> ' + Strings.encodeTags(hit.cosmic_WES_BRCA_MF);
		}
		html += '</td></tr>';
		
		// SCAN-B
		html += '<tr><th title="Mutant Frequency (and count) among reference of 6653 SCAN-B non-replicate samples">SCAN-B MF</th><td>'+Strings.encodeTags(hit.scanb_MF_NR);
		if (hit.scanb_CNT_NR) 
		{
			html += ' (' + Strings.encodeTags(hit.scanb_CNT_NR)+'/6653)';
		}
		html += '</td></tr>';
		
		html += '<tr class="dynamic"><th></th><td style="border-top-width: 1px; border-top-style: dotted;">';
		if (hit.numRba)
		{
			html += '<div class="messagecontainer note" style="margin-top: 1em;">';
			if (hit.numRba == 1)
			{
				html += 'This is the only variant call with this variant.';
			}
			else if (hit.numRba == 2)
			{
				html += 'There is 1 other variant call with this variant.';
			}
			else if (hit.numRba > 2)
			{
				html += 'There are '+(hit.numRba-1)+' other variant calls with this variant.';
			}
			html += '</div>';
		}
		html += '</td></tr>';
		
		Doc.element('hit-summary').innerHTML = html;
		Doc.show('hit-summary', 'table');
	
		// RAW DATA (minimally formatted in separate tab)
		var raw = response.raw;
		
		// Main column
		var fixed = ['CHROM', 'POS', 'ID', 'REF', 'ALT', 'QUAL', 'FILTER'];
		var cols = raw.split('\t');
		var html = '<tbody>';
		for (var i = 0; i < Math.min(fixed.length, cols.length); i++)
		{
			html += '<tr><th>'+fixed[i]+'</th><td>'+Strings.encodeTags(cols[i])+'</td></tr>';
		}
		html += '</tbody>';
		
		// FORMAT columns
		if (cols.length >= 10)
		{
			var format = cols[8].split('\:');
			var gt = cols[9].split('\:');
			html += '<tbody style="border-top-width: 1px; border-top-style: solid;">';
			for (var i = 0; i < Math.min(format.length, gt.length); i++)
			{
				html += '<tr><th>'+Strings.encodeTags(format[i])+'</th><td>'+Strings.encodeTags(gt[i])+'</td></tr>';
			}
			html += '</tbody>';
		}
		
		// INFO columns
		if (cols.length >= 8)
		{
			var info = cols[7].split('\;');
			html += '<tbody style="border-top-width: 1px; border-top-style: solid;">';
			for (var i = 0; i < info.length; i++)
			{
				var keyval = info[i].split('=');
				var key = Strings.encodeTags(keyval[0]);
				var val = Strings.encodeTags(keyval[keyval.length-1]);
				
				// ANN is multi-value separated by ','
				if (key=='ANN' && val.indexOf(',')>0)
				{
					var ann = val.split(',');
					for (var a=0; a<ann.length; a++)
					{
						html += '<tr><th>ANN['+a+']</th><td>'+ann[a]+'</td></tr>';
					}
				}
				else
				{
					val = val.replace(/,/g, ', ');
					html += '<tr><th title="'+key+'">'+key+'</th><td>'+val+'</td></tr>';
				}
			}
			html += '</tbody>';
		}
				
		Doc.element('hit-all').innerHTML = html;
	
	}
	
	details.refAlt = function(ref, alt, maxLength)
	{
		if (!maxLength) maxLength = 15;
		if (ref.length > maxLength) 
		{
			ref = "<span title=\""+ref+"\">"+ref.substring(0, maxLength)+"...</span>";
		}
		if (alt.length > maxLength) 
		{
			alt = "<span title=\""+alt+"\">"+alt.substring(0, maxLength)+"...</span>";
		}
		return ref + "&#8239;›&#8239;" + alt; // &#8239; is a narrow non-breaking space
	}

	
	return details;
}();

Doc.onLoad(HitDetails.initPage);

